﻿


/**
 * wisej.web.ComboBoxEx
 *
 * Extends the wisej.web.ComboBox widget adding a new ShowLoader property to
 * let the combo box display the ajax loaded insted of the dropdown button
 * while loading list items on drop down.
 */
qx.Class.define("wisej.web.ComboBoxEx", {

	extend: wisej.web.ComboBox,

	properties:
	{
		/**
		 * ShowLoader property.
		 *
		 * Shows the loader icon while the combobox is expanding but it doesn't have any items.
		 */
		showLoader: { init: false, check: "Boolean" },

	},

	members: {

		__loaderVisible: false,

		// overridden to hide the loader when the new items are loaded.
		_applyItems: function (value, old) {

			this.base(arguments, value, old);

			if (this.__loaderVisible) {

				// reset the loader.
				this.setEnabled(true);
				this.getChildControl("button").resetIcon();

				// drop down the combo.
				var me = this;
				Wisej.Core.clearAjaxLoader();
				setTimeout(function () {
					me.__loaderVisible = false;
					me.open();
				}, 250);
			}
		},

		// overridden to prevent the drop down from showing when the loader is still activ,e
		_applyDroppedDown: function (value, old)
		{
			if (this.__loaderVisible)
				return;

			this.base(arguments, value, old);
		},

		// override open to show the loader.
		open: function () {

			if (this.isShowLoader() && this.getChildren().length == 0) {

				// show the loader and don't call the base to prevent the drop down from showing.
				this.setEnabled(false);
				this.__loaderVisible = true;
				this.getChildControl("button").setIcon("node-loader");

				// fire the open event on the server.
				this.fireEvent("open");
			}
			else {

				this.base(arguments);

			}
		}
	}
});